@@ -4,7 +4,7 @@
 package Lingua::Interset::Atom;
 use strict;
 use warnings;
-our $VERSION = '3.008';
+our $VERSION = '3.009';
 
 use utf8;
 use open ':utf8';
@@ -326,7 +326,9 @@ sub _get_decision_for_value
     {
         # The sought value could be a list of values.
         # One or more of the hash keys could also be lists of values.
-        my @keys = keys(%{$valuehash});
+        # If there are multiple matching answers and we must select one, we still want the atom to behave deterministically.
+        # Hence we sort the keys (otherwise their order is really random).
+        my @keys = sort(keys(%{$valuehash}));
         my $maxn = 0;
         my $maxkey;
         foreach my $key (@keys)
@@ -397,7 +399,7 @@ Lingua::Interset::Atom - Atomic driver for a surface feature.
 
 =head1 VERSION
 
-version 3.008
+version 3.009
 
 =head1 SYNOPSIS
 
